@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.19 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,18 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.19 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
 {
+    /**
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = 'components.xml';
     /**
      * ٥̾
      * 
@@ -60,24 +67,25 @@ class SyL_ConfigComponents extends SyL_Config
     var $default_priority = 3;
 
     /**
-     * ƥȤ򥻥å
-     * ƥȤʤΤǡåȤʤ褦˥С饤
+     * ե򥻥å
      *
      * @access protected
-     * @param object ȥ饪֥
      */
-    function setContext(&$controller)
+    function setProjectConfigFiles()
     {
+        // Х륳ݡͥե
+        $this->file_names[] = SYL_PROJECT_CONFIG_DIR . "/{$this->config_file_name}";
     }
 
     /**
      * XMLեβϽ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
-        if (SYL_CACHE) {
+        if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_PROJECT_DIR;
             $cache =& $this->getCache($key);
