@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.20 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,18 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.20 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
 {
+    /**
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = 'filters.xml';
     /**
      * ٥̾
      * 
@@ -87,14 +94,34 @@ class SyL_ConfigFilters extends SyL_Config
      */
     var $filter_event_post_render = 'unloadStream';
 
+    /**
+     * ե򥻥å
+     *
+     * @access protected
+     */
+    function setProjectConfigFiles()
+    {
+        // ץꥱե륿ե
+        $config = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+        if (is_file($config)) {
+            $this->file_names[] = $config;
+        }
+        // Хե륿ե
+        $config = SYL_PROJECT_CONFIG_DIR . "/{$this->config_file_name}";
+        if (is_file($config)) {
+            $this->file_names[] = $config;
+        }
+    }
+
     /**
      * XMLեβϽ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
-        if (SYL_CACHE) {
+        if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_APP_DIR . $this->context->getActionFile();
             $cache =& $this->getCache($key);
