@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.10 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.10 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -64,6 +64,24 @@ class SyL_ContextJs extends SyL_Context
      */
     var $view_type = 'js.default';
 
+    /**
+     * 󥹥ȥ饯
+     *
+     * @access public
+     * @param object ȥ饪֥
+     * @param object ǡ֥
+     */
+    function SyL_ContextJs(&$controller, &$data)
+    {
+        // JSݡȽ
+        if ($data->getImport()) {
+            $this->is_execute = false;
+            $this->setViewType('js.default');
+        } else {
+            parent::SyL_Context($controller, $data);
+        }
+    }
+
     /**
      * ꥯȥ֥Ȥ
      *
