@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataCmd.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataCmd.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataCmd.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataCmd.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataCmd extends SyL_Data
@@ -56,29 +56,36 @@ class SyL_DataCmd extends SyL_Data
 
         $i = 0;
         $tmp_arg = null;
+        $parameters = array();
         foreach ($args as $arg) {
-            if (substr($arg, 0, 1) == '-') {
-                if (strlen($arg) > 1) {
-                    $tmp_arg = substr($arg, 1);
-                    $value = $this->get($tmp_arg);
-                    if ($value !== null) {
-                        array_push($value, null);
-                        $this->set($tmp_arg, $value);
-                    } else {
-                        $this->set($tmp_arg, array(null));
-                    }
+            if ((substr($arg, 0, 2) == '--') && (strlen($arg) > 2)) {
+                $tmp_args = explode('=', substr($arg, 2), 2);
+                $tmp = (count($tmp_args) > 1) ? $tmp_args[1] : null;
+                if (isset($parameters[$tmp_args[0]])) {
+                    $parameters[$tmp_args[0]][] = $tmp;
+                } else {
+                    $parameters[$tmp_args[0]] = array($tmp);
+                }
+                $tmp_arg = null;
+            } else if ((substr($arg, 0, 1) == '-') && (strlen($arg) > 1)) {
+                $tmp_arg = substr($arg, 1);
+                if (isset($parameters[$tmp_arg])) {
+                    $parameters[$tmp_arg][] = null;
+                } else {
+                    $parameters[$tmp_arg] = array(null);
                 }
             } else {
                 if ($tmp_arg !== null) {
-                    $value = $this->get($tmp_arg);
-                    $value[count($value)-1] = $arg;
-                    $this->set($tmp_arg, $value);
+                    $cnt = count($parameters[$tmp_arg])-1;
+                    $parameters[$tmp_arg][$cnt] = $arg;
                     $tmp_arg = null;
                 } else {
-                    $this->set($i++, $arg);
+                    $parameters[$i++] = $arg;
                 }
             }
         }
+
+        $this->setInputs($parameters);
     }
 
     /**
