@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.25 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.26 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.25 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.26 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -60,11 +60,14 @@ class SyL_ErrorWeb extends SyL_Error
      */
     function forward404Detail()
     {
-        SyL_Loggers::notice("404 Not Found");
-        SyL_Response::setStatusHeader('404');
-
-        include_once SYL_ERROR_FORWARD_FILE_404;
-        exit;
+        // 쥯Ƚ
+        if (preg_match('/^(redirect\:\:)(.+)$/', SYL_ERROR_FORWARD_FILE_404, $matches)) {
+            SyL_Response::redirect($matches[2]);
+        } else {
+            SyL_Loggers::notice("404 Not Found");
+            SyL_Response::setStatusHeader('404');
+            include_once SYL_ERROR_FORWARD_FILE_404;
+        }
     }
 
     /**
@@ -76,6 +79,11 @@ class SyL_ErrorWeb extends SyL_Error
      */
     function displayError($error_messages, $_error_trace)
     {
+        // 쥯Ƚ
+        if (preg_match('/^(redirect\:\:)(.+)$/', SYL_ERROR_FORWARD_FILE, $matches)) {
+            SyL_Response::redirect($matches[2]);
+            return;
+        }
         // display_errorsoffξϥ顼̤ɽʤ
         if (!ini_get('display_errors')) {
             return;
@@ -83,7 +91,6 @@ class SyL_ErrorWeb extends SyL_Error
 
         // 顼å
         $_error_message = implode('<br>', $error_messages);
-
         // 顼
         $_error_lines = array();
 
