@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -78,14 +78,14 @@ class SyL_ActionForm extends SyL_Form
      * @param string URL
      * @return object ե४֥
      */
-    function &factory($formpath, $action='')
+    function &factory($classpath, $action='')
     {
         static $forms = array();
-        if (!isset($forms[$formpath])) {
-            $classname = SyL_Loader::convertClass($formpath, true);
-            $forms[$formpath] = new $classname($action);
+        if (!isset($forms[$classpath])) {
+            $classname = class_exists($classpath) ? $classpath : SyL_Loader::convertClass($classpath, true);
+            $forms[$classpath] = new $classname($action);
         }
-        return $forms[$formpath];
+        return $forms[$classpath];
     }
 
     /**
