@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.21 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.21 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
@@ -186,11 +186,11 @@ class SyL_Config extends SyL_XmlReader
         }
 
         $cache =& SyL_Cache::factory(SYL_CACHE);
-        $cache->setPrefix(basename($this->file_names[0]) . '.');
+        $cache->setPrefix(SYL_APP_NAME . '.');
         $cache->setKey($key);
         $cache->setMinModifyTime($mtime);
         if (defined('SYL_CACHE_FILE_DIR') && SYL_CACHE_FILE_DIR) {
-            $cache->setCacheDir(SYL_CACHE_FILE_DIR . SYL_APP_NAME . '/config/' . basename($this->file_names[0]) . '/');
+            $cache->setCacheDir(SYL_CACHE_FILE_DIR . '/config/' . basename($this->file_names[0]) . '/');
         }
 
         //$cache->useIncludeCache();
