@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.34 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.35 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -64,7 +64,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.34 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.35 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -160,11 +160,7 @@ class SyL_Controller
         define('SYL_CACHE', (isset($config['cache']) && $config['cache']) ? $config['cache'] : false);
         switch (SYL_CACHE) {
         case 'file':
-            if (isset($config['cache_dir']) && $config['cache_dir']) {
-                define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . $config['cache_dir']);
-            } else {
-                define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . '/var/cache/');
-            }
+            define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . '/var/cache/' . SYL_APP_NAME . '/');
             break;
         case 'memcache':
             if (isset($config['cache_host']) && $config['cache_host']) {
