@@ -27,15 +27,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheFile.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheFile.php,v 1.7 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-if (!defined('SYL_CACHE_FILE_DIR')) {
-    define('SYL_CACHE_FILE_DIR', '/tmp/');
-}
-
 /**
  * ե륭å奯饹
  *
@@ -43,7 +39,7 @@ if (!defined('SYL_CACHE_FILE_DIR')) {
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheFile.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheFile.php,v 1.7 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_CacheFile extends SyL_Cache
@@ -54,7 +50,7 @@ class SyL_CacheFile extends SyL_Cache
      * @access private
      * @var string
      */
-    var $cache_dir = SYL_CACHE_FILE_DIR;
+    var $cache_dir = '/tmp/';
     /**
      * 󥯥롼ɥåѥե饰
      *
@@ -76,6 +72,13 @@ class SyL_CacheFile extends SyL_Cache
      * @var bool
      */
     var $serial = true;
+    /**
+     * Υåե̾
+     *
+     * @access private
+     * @var bool
+     */
+    var $lockname = '.locking';
 
     /**
      * åǥ쥯ȥ򥻥åȤ
@@ -281,7 +284,6 @@ class SyL_CacheFile extends SyL_Cache
         }
 
         fwrite($fp, $data, $size);
-        flock($fp, LOCK_UN);
         fclose($fp);
 
         @chmod($filename, 0777);
@@ -314,25 +316,48 @@ class SyL_CacheFile extends SyL_Cache
             return;
         }
 
+        $lockfile = "{$this->cache_dir}/__{$this->prefix}{$this->lockname}";
+        if (is_file($lockfile)) {
+            // åե뤬ϡԤʤ
+            return;
+        }
+
+        $fp = @fopen($lockfile, 'wb');
+        if (!$fp) return;
+        if (!@flock($fp, LOCK_EX)) {
+            fclose($fp);
+            return;
+        }
+
         $now = time();
 
         $dh = opendir($this->cache_dir);
         while (($filename = readdir($dh)) !== false) {
-            if (is_file($this->cache_dir . $filename)) {
-                $mtime = filemtime($this->cache_dir . $filename);
+            $filename = basename($filename);
+            if (is_file("{$this->cache_dir}/{$filename}")) {
+                if ($this->prefix) {
+                    if (!preg_match('/^(' . preg_quote($this->prefix, '/') . ')/', $filename)) {
+                        continue;
+                    }
+                }
+                $filename = "{$this->cache_dir}/{$filename}";
+                $mtime = filemtime($filename);
                 // ֤κǾȽ
-                if (($this->min_mtime > 0) && ($mtime < $this->min_mtime)) {
-                    @unlink($this->cache_dir . $filename);
+                if ($this->min_mtime && ($mtime < $this->min_mtime)) {
+                    @unlink($filename);
                 // ֤κȽ
-                } else if (($this->max_mtime > 0) && ($mtime > $this->max_mtime)) {
-                    @unlink($this->cache_dir . $filename);
+                } else if ($this->max_mtime && ($mtime > $this->max_mtime)) {
+                    @unlink($filename);
                 // ¸֤Ƚ
                 } else if ($now > ($mtime + $this->life_time)) {
-                    @unlink($this->cache_dir . $filename);
+                    @unlink($filename);
                 }
             }
         }
         closedir($dh);
+
+        fclose($fp);
+        @unlink($lockfile);
     }
 
     /**
@@ -346,6 +371,19 @@ class SyL_CacheFile extends SyL_Cache
             trigger_error("[SyL error] Cache directory property not set ({$this->cache_dir})", E_USER_ERROR);
         }
 
+        $lockfile = "{$this->cache_dir}/__{$this->prefix}{$this->lockname}";
+        if (is_file($lockfile)) {
+            // åե뤬ϡԤʤ
+            return;
+        }
+
+        $fp = @fopen($lockfile, 'w');
+        if (!$fp) return;
+        if (!@flock($fp, LOCK_EX)) {
+            fclose($fp);
+            return;
+        }
+
         $dh = opendir($this->cache_dir);
         while (($filename = readdir($dh)) !== false) {
             if (is_file($this->cache_dir . $filename)) {
@@ -353,6 +391,9 @@ class SyL_CacheFile extends SyL_Cache
             }
         }
         closedir($dh);
+
+        fclose($fp);
+        @unlink($lockfile);
     }
 
     /**
