@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilCompositeLeaf.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilCompositeLeaf.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ require_once 'SyL_UtilCompositeComponent.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilCompositeLeaf.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilCompositeLeaf.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilCompositeLeaf extends SyL_CompositeComponent
@@ -59,6 +59,17 @@ class SyL_UtilCompositeLeaf extends SyL_CompositeComponent
     {
         parent::SyL_CompositeComponent($name);
     }
+
+    /**
+     * Ǥɲä
+     *
+     * @access public
+     * @param object 
+     */
+    function add($entry)
+    {
+        trigger_error("[SyL error] `Add' method not use in this object (" . get_class($this) . ")", E_USER_ERROR);
+    }
 }
 
 ?>
