@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.6 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.6 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorCompare extends SyL_ValidationValidator
@@ -119,11 +119,9 @@ class SyL_ValidationValidatorCompare extends SyL_ValidationValidator
         }
 
         $js  = '';
-        $js .= 'if (!error_message) {' . "\n";
-        $js .= '  var error_message_tmp = validation.isCompare(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
-        $js .= '  if (error_message_tmp) {' . "\n";
-        $js .= '    error_message = error_message_tmp;' . "\n";
-        $js .= '  }' . "\n";
+        $js .= 'var message_tmp = validation.isCompare(name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
+        $js .= 'if (message_tmp) {' . "\n";
+        $js .= '  message = message_tmp;' . "\n";
         $js .= '}' . "\n";
 
         return $js;
