@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceCategoryCategoryRequest.php,v 1.2 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceCategoryCategoryRequest.php,v 1.3 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -49,7 +49,7 @@ require_once 'SyL_WebServiceCategoryCategoryResponse.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceCategoryCategoryRequest.php,v 1.2 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceCategoryCategoryRequest.php,v 1.3 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebServiceCategoryCategoryRequest extends SyL_WebServiceYahoo_co_jpRequest
@@ -60,7 +60,7 @@ class SyL_WebServiceCategoryCategoryRequest extends SyL_WebServiceYahoo_co_jpReq
      * @access protected
      * @var string
      */
-    var $host = 'api.dir.yahoo.co.jp';
+    var $host = 'dir.yahooapis.jp';
     /**
      * ¹URLѥ
      *
