@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -291,13 +291,39 @@ class Index extends AppAction
             }
         }
 
+        // -------------------------------------------------
+        // եå
+        // -------------------------------------------------
+        $project_config_file = $project_dir . '/config/defines.xml';
+        $app_config_file     = $app_dir . '/config/defines.xml';
+
+        if (!is_file($project_config_file)) {
+            trigger_error("[SyL error] `defines.xml' not found in project directory({$project_config_file})", E_USER_ERROR);
+        }
+
+        // -------------------------------------------------
+        // ե
+        // -------------------------------------------------
+        $cmd->stdout("  project config getting...");
+
+        $config =& SyL_Config::factory('defines');
+        $config->setConfigFiles(array($app_config_file, $project_config_file));
+        $config->parseXml(false);
+        $values = $config->getConfig();
+
+        if (!isset($values['SYL_DB_DSN']) || !$values['SYL_DB_DSN']) {
+            trigger_error("[SyL error] `SYL_DB_DSN' constant not defined in config file({$project_config_file} or {$app_config_file})", E_USER_ERROR);
+        }
+
+        $connection_string = $values['SYL_DB_DSN'];
+
         // -------------------------------------------------
         // ơ֥륹޼
         // -------------------------------------------------
         $cmd->stdout("  table schema scaning...");
 
         // ơ֥륹޼
-        $conn =& SyL_DB::getConnection();
+        $conn =& SyL_DB::getConnection($connection_string);
         $schema =& $conn->getSchema();
         $table_columns  = $schema->getColumns($tablename);
         $table_primary  = $schema->getPrimary($tablename);
