@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Action.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Action.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,22 +39,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Action.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Action.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Action extends AppAction
 {
     var $c_action; // 󥸥
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function Action()
-    {
-    }
-
     /**
      * 
      *
@@ -64,24 +55,22 @@ class Action extends AppAction
      */
     function execute(&$data, &$context)
     {
-        $project_dir  = $data->get('d');
-        $app_name     = $data->get('w');
-        $action_files = $data->get('a');
+        $project_dir  = $data->geta('d', 0);
+        $app_name     = $data->geta('w', 0);
+        $action_files = $data->geta('a');
+
+        $cmd =& $context->getConsole();
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
         // -------------------------------------------------
-        $cnt = count($project_dir);
-        if ($cnt == 0) {
+        if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Project directory (-d) only 1", E_USER_ERROR);
-            exit;
         }
-
-        $project_dir = preg_match('/(\\\\|\/)$/', $project_dir[0]) ? $project_dir[0] : $project_dir[0] . '/';
-
+        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
+            $project_dir .= '/';
+        }
         if (!file_exists($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
             exit;
@@ -90,42 +79,34 @@ class Action extends AppAction
         // -------------------------------------------------
         // ץꥱ̾å
         // -------------------------------------------------
-        $cnt = count($app_name);
-        if ($cnt == 0) {
+        if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Application name (-w) only 1", E_USER_ERROR);
-            exit;
-        } else if (!preg_match('/^[\w\-]+$/', $app_name[0])) {
+        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
             trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
             exit;
-        } else {
-            $app_name = $app_name[0];
         }
 
-        $app_dir = $project_dir . 'app/' . $app_name . '/';
-
+        $app_dir = "{$project_dir}apps/{$app_name}/";
         if (!file_exists($app_dir)) {
-            trigger_error("[SyL error] Application directory not found ({$project_dir})", E_USER_ERROR);
+            trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
             exit;
         }
 
         // -------------------------------------------------
         // եå
         // -------------------------------------------------
-        $action_dir = $app_dir . 'actions/';
-        $cnt = count($action_files);
-        if ($cnt == 0) {
-            trigger_error("[SyL error] Action file not found", E_USER_ERROR);
+        if (!is_array($action_files)) {
+            trigger_error("[SyL error] Action file (-a) not found", E_USER_ERROR);
             exit;
         }
 
+        $action_dir = "{$app_dir}actions/";
         foreach ($action_files as $action_file) {
-            if (!preg_match('/^(\\\\|\/)/', $action_file)) {
-                $action_file = '/' . $action_file;
+            if (preg_match('/^(\\\\|\/)/', $action_file)) {
+                $action_file = substr($action_file, 1);
             }
-            if (substr($action_file, -4) != '.php') {
+            if (!preg_match('/\.php$/', $action_file)) {
                 $action_file .= '.php';
             }
             if (file_exists($action_dir . $action_file)) {
@@ -134,10 +115,11 @@ class Action extends AppAction
             }
         }
 
+
         // -------------------------------------------------
         // ե
         // -------------------------------------------------
-        $this->c_action->trigger($project_dir, $app_name, $action_files);
+        $this->c_action->trigger($cmd, $project_dir, $app_name, $action_files);
     }
 
 }
