@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Application.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Application.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Application.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Application.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Application extends AppAction
@@ -49,15 +49,6 @@ class Application extends AppAction
     var $c_controller; // 󥸥
     var $c_template; // 󥸥
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function Application()
-    {
-    }
-
     /**
      * ץꥱ
      *
@@ -67,28 +58,22 @@ class Application extends AppAction
      */
     function execute(&$data, &$context)
     {
-        $project_dir     = $data->get('d');
-        $app_name        = $data->get('w');
-        $controller_file = $data->get('c');
-        //$action_files    = $data->get('a');
-        //$template_files  = $data->get('t');
+        $project_dir     = $data->geta('d', 0);
+        $app_name        = $data->geta('w', 0);
+        $controller_file = $data->geta('c', 0);
 
         $cmd =& $context->getConsole();
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
         // -------------------------------------------------
-        $cnt = count($project_dir);
-        if ($cnt == 0) {
+        if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Project directory (-d) only 1", E_USER_ERROR);
-            exit;
         }
-
-        $project_dir = preg_match('/(\\\\|\/)$/', $project_dir[0]) ? $project_dir[0] : $project_dir[0] . '/';
-
+        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
+            $project_dir .= '/';
+        }
         if (!file_exists($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
             exit;
@@ -97,24 +82,19 @@ class Application extends AppAction
         // -------------------------------------------------
         // ץꥱ̾å
         // -------------------------------------------------
-        $cnt = count($app_name);
-        if ($cnt == 0) {
+        if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Application name (-w) only 1", E_USER_ERROR);
-            exit;
-        } else if (!preg_match('/^[\w\-]+$/', $app_name[0])) {
+        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
             trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
             exit;
-        } else {
-            $app_name = $app_name[0];
         }
 
-        $app_dir = $project_dir . 'app/' . $app_name . '/';
+        $app_dir = "{$project_dir}apps/{$app_name}/";
 
         if (file_exists($app_dir)) {
-            if ($cmd->getInput('', "create application ({$app_dir}) [Y/n]:") != 'Y') {
+            if ($cmd->getInput('Already application directory exists', "overwrite application ({$app_dir}) [Y/n]:") != 'Y') {
+                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                 exit;
             }
             if (!is_writable($app_dir)) {
@@ -122,7 +102,8 @@ class Application extends AppAction
                 exit;
             }
         } else {
-            if ($cmd->getInput('', "create directory ({$app_dir}) [Y/n]:") != 'Y') {
+            if ($cmd->getInput('', "create application ({$app_dir}) [Y/n]:") != 'Y') {
+                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                 exit;
             }
         }
@@ -130,19 +111,10 @@ class Application extends AppAction
         // -------------------------------------------------
         // ȥեå
         // -------------------------------------------------
-        $cnt = count($controller_file);
-        if ($cnt == 0) {
-            $controller_file = '';
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Controller file (-c) only 1", E_USER_ERROR);
-            exit;
-        } else {
-            $controller_file = $controller_file[0];
-        }
-
         if ($controller_file) {
             if (file_exists($controller_file)) {
                 if ($cmd->getInput('Already controller file exists', "overwrite controller file ({$controller_file}) [Y/n]:") != 'Y') {
+                    $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                     exit;
                 }
                 if (!is_writable($controller_file)) {
@@ -170,28 +142,24 @@ class Application extends AppAction
         // -------------------------------------------------
         // ץꥱ
         // -------------------------------------------------
-        $this->c_application->trigger($project_dir, $app_name);
+        $this->c_application->trigger($cmd, $project_dir, $app_name);
 
         // -------------------------------------------------
         // ȥե
         // -------------------------------------------------
         if ($controller_file) {
-            $this->c_controller->trigger($project_dir, $app_name, $controller_file);
+            $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
         }
 
         // -------------------------------------------------
         // ե
         // -------------------------------------------------
-        if (count($action_files) > 0) {
-            $this->c_action->trigger($project_dir, $app_name, $action_files);
-        }
+        $this->c_action->trigger($cmd, $project_dir, $app_name, $action_files);
 
         // -------------------------------------------------
         // ƥץ졼ȥե
         // -------------------------------------------------
-        if (count($template_files) > 0) {
-            $this->c_template->trigger($project_dir, $app_name, $template_files);
-        }
+        $this->c_template->trigger($cmd, $project_dir, $app_name, $template_files);
     }
 
 }
