@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Controller.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Controller.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,22 +39,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Controller.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Controller.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Controller extends AppAction
 {
     var $c_controller; // 󥸥
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function Controller()
-    {
-    }
-
     /**
      * ȥ
      *
@@ -64,24 +55,22 @@ class Controller extends AppAction
      */
     function execute(&$data, &$context)
     {
-        $project_dir     = $data->get('d');
-        $app_name        = $data->get('w');
-        $controller_file = $data->get('c');
+        $project_dir     = $data->geta('d', 0);
+        $app_name        = $data->geta('w', 0);
+        $controller_file = $data->geta('c', 0);
+
+        $cmd =& $context->getConsole();
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
         // -------------------------------------------------
-        $cnt = count($project_dir);
-        if ($cnt == 0) {
+        if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Project directory (-d) only 1", E_USER_ERROR);
-            exit;
         }
-
-        $project_dir = preg_match('/(\\\\|\/)$/', $project_dir[0]) ? $project_dir[0] : $project_dir[0] . '/';
-
+        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
+            $project_dir .= '/';
+        }
         if (!file_exists($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
             exit;
@@ -90,42 +79,24 @@ class Controller extends AppAction
         // -------------------------------------------------
         // ץꥱ̾å
         // -------------------------------------------------
-        $cnt = count($app_name);
-        if ($cnt == 0) {
+        if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Application name (-w) only 1", E_USER_ERROR);
-            exit;
-        } else if (!preg_match('/^[\w\-]+$/', $app_name[0])) {
+        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
             trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
             exit;
-        } else {
-            $app_name = $app_name[0];
         }
 
-        $app_dir = $project_dir . 'app/' . $app_name . '/';
-
+        $app_dir = "{$project_dir}apps/{$app_name}/";
         if (!file_exists($app_dir)) {
-            trigger_error("[SyL error] Application directory not found ({$project_dir})", E_USER_ERROR);
+            trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
             exit;
         }
 
         // -------------------------------------------------
         // ȥեå
         // -------------------------------------------------
-        $cnt = count($controller_file);
-        if ($cnt == 0) {
-            trigger_error("[SyL error] Controller file (-c) not found", E_USER_ERROR);
-            exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Controller file (-c) only 1", E_USER_ERROR);
-            exit;
-        } else {
-            $controller_file = $controller_file[0];
-        }
-
-        if (!file_exists($controller_file)) {
+        if (file_exists($controller_file)) {
             trigger_error("[SyL error] Already controller file exists ({$controller_file})", E_USER_ERROR);
             exit;
         }
@@ -134,7 +105,7 @@ class Controller extends AppAction
         // -------------------------------------------------
         // ȥե
         // -------------------------------------------------
-        $this->c_controller->trigger($project_dir, $app_name, $controller_file);
+        $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
     }
 
 }
