@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateProject.php,v 1.5 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateProject.php,v 1.5 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateProject
@@ -50,8 +50,9 @@ class CreateProject
      * @access public
      * @param object 󥽡륪֥
      * @param string ץȥǥ쥯ȥ
+     * @param string Smartyǥ쥯ȥ
      */
-    function trigger(&$cmd, $project_dir)
+    function trigger(&$cmd, $project_dir, $smarty_dir)
     {
         if (!is_dir($project_dir)) {
             if (!mkdir($project_dir, 0755)) {
@@ -66,14 +67,12 @@ class CreateProject
           'lib'         => 0755,
           'lib/Common'  => 0755,
           'var'         => 0755,
-          'var/logs'    => 0777,
           'var/cache'   => 0777,
+          'var/logs'    => 0755,
           'var/session' => 0777,
           'var/skel-templates' => 0755,
           'var/smarty'         => 0755,
-          'var/smarty/cache'   => 0777,
-          'var/smarty/configs' => 0777,
-          'var/smarty/templates_c' => 0777
+          'var/upload'  => 0777,
         );
 
         $files = array(
@@ -94,10 +93,25 @@ class CreateProject
 
         foreach ($files as $file_org => $file_dist) {
             $cmd->stdout("  -> copying file {$project_dir}{$file_dist}");
-            if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
-                copy("{$project_dir}var/skel-templates/{$file_org}", "{$project_dir}{$file_dist}");
-            } else {
-                copy(SYL_PROJECT_DIR . "/var/skel-templates/{$file_org}", "{$project_dir}{$file_dist}");
+            switch ($file_org) {
+            case 'defines.xml':
+                $trans = array(
+                  '{{SYL_SMARTY_DIR}}' => $smarty_dir
+                );
+                $contents = is_file("{$project_dir}var/skel-templates/{$file_org}")
+                          ? file_get_contents("{$project_dir}var/skel-templates/{$file_org}")
+                          : file_get_contents(SYL_PROJECT_DIR . "/var/skel-templates/{$file_org}");
+                $contents = strtr($contents, $trans);
+                $fp = fopen($project_dir . $file_dist, 'wb');
+                fwrite($fp, $contents);
+                fclose($fp);
+                break;
+            default:
+                if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
+                    copy("{$project_dir}var/skel-templates/{$file_org}", "{$project_dir}{$file_dist}");
+                } else {
+                    copy(SYL_PROJECT_DIR . "/var/skel-templates/{$file_org}", "{$project_dir}{$file_dist}");
+                }
             }
         }
 
