@@ -4,7 +4,7 @@
 /**
  * ȥȥ饯饹ɤ߹
  */
-require_once '{SYL_DIR}/SyL.php';
+require_once '{{SYL_DIR}}/SyL.php';
 
 /**
  * ưѥ᡼
@@ -15,8 +15,8 @@ require_once '{SYL_DIR}/SyL.php';
  *  cache       - åˡʢ̤ϤǥåѤʤ
  */
 $config = array(
-  'project_dir'  => '{PROJECT_DIR}',
-  'app_name'     => '{APP_NAME}',
+  'project_dir'  => '{{PROJECT_DIR}}',
+  'app_name'     => '{{APP_NAME}}',
   'action_key'   => 'action',
   'cache'        => 'file'
 );
